import jwt
import datetime
from typing import Union

SECRET_KEY = "G7#k9v@2qP!x4Z$1" 
ALGORITHM = "HS256"  

def generate_jwt(payload: dict, expires_in: int = 3600) -> str:
    """
    Generate a JWT token.
    :param payload: Dictionary containing user data.
    :param expires_in: Expiry time in seconds (default: 1 hour).
    :return: Encoded JWT token as a string.
    """
    expiration = datetime.datetime.utcnow() + datetime.timedelta(seconds=expires_in)
    payload["exp"] = expiration
    token = jwt.encode(payload, SECRET_KEY, algorithm=ALGORITHM)
    return token

def verify_jwt(token: str) -> Union[dict, None]:
    """
    Verify and decode a JWT token.
    :param token: JWT token string.
    :return: Decoded payload if valid, None if invalid.
    """
    try:
        decoded_token = jwt.decode(token, SECRET_KEY, algorithms=[ALGORITHM])
        return decoded_token
    except jwt.ExpiredSignatureError:
        print("Token has expired")
    except jwt.InvalidTokenError:
        print("Invalid token")
    return None
